@@ -1,6 +1,6 @@
 # Copyright 1999-2004 Gentoo Technologies, Inc.
 # Distributed under the terms of the GNU General Public License v2
-# $Header: /home/cvsroot/gentoo-src/rc-scripts/sbin/functions.sh,v 1.51 2004/04/24 02:07:00 agriffis Exp $
+# $Header: /home/cvsroot/gentoo-src/rc-scripts/sbin/functions.sh,v 1.52 2004/05/21 15:22:12 agriffis Exp $
 
 RC_GOT_FUNCTIONS="yes"
 
@@ -616,10 +616,7 @@ get_KV() {
 #   EXAMPLE:  if get_bootparam "nodevfs" ; then ....
 #
 get_bootparam() {
-	local x=
-	local copt=
-	local parms=
-	local retval=1
+	local x copt params retval=1
 
 	[ ! -e "/proc/cmdline" ] && return 1
 	
