@@ -1,8 +1,7 @@
 #!/bin/bash
-# Copyright 1999-2003 Gentoo Technologies, Inc.
+# Copyright 1999-2004 Gentoo Technologies, Inc.
 # Distributed under the terms of the GNU General Public License v2
-# $Header: /home/cvsroot/gentoo-src/rc-scripts/sbin/runscript.sh,v 1.30 2004/02/26 17:29:43 azarah Exp $
-
+# $Header: /home/cvsroot/gentoo-src/rc-scripts/sbin/runscript.sh,v 1.32 2004/05/05 21:11:31 agriffis Exp $
 
 # Common functions
 [ "${RC_GOT_FUNCTIONS}" != "yes" ] && source /sbin/functions.sh
@@ -11,6 +10,12 @@
 # Functions to control daemons
 [ "${RC_GOT_DAEMON}" != "yes" ] && source "${svclib}/sh/rc-daemon.sh"
 
+# Fix bug 48595
+if [[ $(id -u) != 0 ]]; then
+	eerror "ERROR: must be root to run init scripts"
+	exit 1
+fi
+
 # State variables
 svcpause="no"
 svcrestart="no"
@@ -427,7 +432,7 @@ svc_homegrown() {
 shift
 if [ "$#" -lt 1 ]
 then
-	eerror "ERROR:  not enough args."
+	eerror "ERROR: not enough args."
 	usage ${opts}
 	exit 1
 fi
